Index: /issm/trunk-jpl/src/c/solutions/issm.cpp
===================================================================
--- /issm/trunk-jpl/src/c/solutions/issm.cpp	(revision 13444)
+++ /issm/trunk-jpl/src/c/solutions/issm.cpp	(revision 13445)
@@ -80,9 +80,4 @@
 	/*out of solution_type, figure out types of analyses needed in the femmodel: */
 	AnalysisConfiguration(&analyses,&numanalyses,solution_type);
-
-	/*before we create the model, start the trace on for AD mode: */
-	#ifdef _HAVE_ADOLC_
-	trace_on(1);
-	#endif
 
 	/*Create femmodel, using input file: */

Index: /issm/trunk-jpl/src/c/classes/IoModel.cpp
===================================================================
--- /issm/trunk-jpl/src/c/classes/IoModel.cpp	(revision 13444)
+++ /issm/trunk-jpl/src/c/classes/IoModel.cpp	(revision 13445)
@@ -53,5 +53,5 @@
 	for(int i=0;i<MaximumNumberOfEnums;i++) this->data[i]=NULL;
 
 	/*If we are running in AD mode, we need to declare our independent variables now, 
 	 *and prevent them from being erased during successive calls to iomodel->FetchConstants, iomodel->FetchData and 
 	 iomodel->DeleteData:*/
@@ -220,8 +220,12 @@
 	this->FetchData(&autodiff,AutodiffIsautodiffEnum);
 	if(autodiff){
-	
+
 		this->FetchData(&numberofvertices,MeshNumberofverticesEnum);
 		
 		#ifdef _HAVE_ADOLC_
+
+		/*Start the trace: */
+		trace_on(1);
+
 		/*build dataset made of independent objects: */
 		this->independent_objects=new DataSet();
@@ -53,5 +53,5 @@
 	for(int i=0;i<MaximumNumberOfEnums;i++) this->data[i]=NULL;
 
-	/*If we are running in AD mode, we need to declare our independent variables now, 
+	/*If we are running in AD mode, we need to start the trace and declare our independent variables now, 
 	 *and prevent them from being erased during successive calls to iomodel->FetchConstants, iomodel->FetchData and 
 	 iomodel->DeleteData:*/